Module core

Module core 

Structs

DiskIndexBuilderCore
Core shared functionality between sync and async disk index builders. Contains only fields and methods that are truly needed by both builder types.