pub struct DiskIndexBuilderCore<'a, Data, StorageProvider>where
Data: GraphDataType<VectorIdType = u32>,
StorageProvider: StorageReadProvider + StorageWriteProvider,{
pub index_writer: DiskIndexWriter,
pub pq_storage: PQStorage,
pub disk_build_param: DiskIndexBuildParameters,
pub index_configuration: IndexConfiguration,
pub chunking_config: ChunkingConfig,
pub checkpoint_record_manager: Box<dyn CheckpointManager>,
pub storage_provider: &'a StorageProvider,
pub _phantom: PhantomData<Data>,
}Expand description
Core shared functionality between sync and async disk index builders. Contains only fields and methods that are truly needed by both builder types.
Fields
index_writer: DiskIndexWriterpq_storage: PQStoragedisk_build_param: DiskIndexBuildParametersindex_configuration: IndexConfigurationchunking_config: ChunkingConfigcheckpoint_record_manager: Box<dyn CheckpointManager>storage_provider: &'a StorageProvider_phantom: PhantomData<Data>Auto Trait Implementations
impl<'a, Data, StorageProvider> Freeze for DiskIndexBuilderCore<'a, Data, StorageProvider>
impl<'a, Data, StorageProvider> !RefUnwindSafe for DiskIndexBuilderCore<'a, Data, StorageProvider>
impl<'a, Data, StorageProvider> Send for DiskIndexBuilderCore<'a, Data, StorageProvider>
impl<'a, Data, StorageProvider> Sync for DiskIndexBuilderCore<'a, Data, StorageProvider>
impl<'a, Data, StorageProvider> Unpin for DiskIndexBuilderCore<'a, Data, StorageProvider>where
Data: Unpin,
impl<'a, Data, StorageProvider> UnsafeUnpin for DiskIndexBuilderCore<'a, Data, StorageProvider>
impl<'a, Data, StorageProvider> !UnwindSafe for DiskIndexBuilderCore<'a, Data, StorageProvider>