pub struct CheckpointRecord { /* private fields */ }Expand description
Represents a checkpoint record in the index build process. The checkpoint record can be marked as in-valid to indicate that the exising intermediate data should be discarded. This can happen because of a crash or an unexpected shutdown during the in-memory index build.
Implementations
Sourceimpl CheckpointRecord
impl CheckpointRecord
Sourcepub fn new() -> CheckpointRecord
pub fn new() -> CheckpointRecord
Create a new CheckpointRecord with the work type set to Start.
pub fn is_valid(&self) -> bool
pub fn get_resumption_point(&self, stage: WorkStage) -> Option<usize>
pub fn advance_work_type( &self, next_stage: WorkStage, ) -> ANNResult<CheckpointRecord>
pub fn mark_as_invalid(&self) -> CheckpointRecord
pub fn update_progress(&self, progress: usize) -> CheckpointRecord