Module data_model
diskann_
disk
0.50.1
Module data_
model
Module Items
Re-exports
Modules
Structs
Enums
In crate diskann_
disk
diskann_disk
Module
data_
model
Re-exports

pub use graph_data_types::
AdHoc
;
pub use graph_data_types::
GraphDataType
;
Modules

graph_
data_
types
Structs

Cache
Graph
Header
GraphHeader. The header is stored in the first sector of the disk index file, or the first segment of the JET stream.
Graph
Layout
Version
Graph layout version. In the format of
major.minor
.
Graph
Metadata
Index graph metadata. The metadata is stored in the first sector of the disk index file, or the first segment of the BigStorageStream. The metadata is like a “header” of the index graph.
Enums

Caching
Strategy