GraphHeader

Struct GraphHeader 

pub struct GraphHeader { /* private fields */ }
GraphHeader. The header is stored in the first sector of the disk index file, or the first segment of the JET stream.

Implementations

Source

impl GraphHeader

pub const CURRENT_LAYOUT_VERSION: GraphLayoutVersion

Update the layout version when the GraphHeader layout is modified.

pub fn new( metadata: GraphMetadata, block_size: u64, layout_version: GraphLayoutVersion, ) -> Self

pub fn to_bytes(&self) -> ANNResult<Vec<u8>>

Serialize the GraphHeader object to a byte vector. Layout: | GraphMetadata (80 bytes) | BlockSize (8 bytes) | GraphLayoutVersion (8 bytes) |

pub fn get_size() -> usize

Get the size of the header after serialization.

pub fn metadata(&self) -> &GraphMetadata

pub fn block_size(&self) -> u64

pub fn layout_version(&self) -> &GraphLayoutVersion

pub fn max_degree<DataType>(&self) -> Result<usize, GraphHeaderError>

Returns the maximum degree of the graph

Type Parameters
  • DataType - The type of vector data stored in the graph nodes