pub fn quantizer_preprocess(
pq_scratch: &mut PQScratch,
pq_data: &PQData,
metric: Metric,
id_to_calculate_pq_distance: &[u32],
) -> ANNResult<()>Expand description
Preprocesses the query vector for PQ distance calculations. This function rotates the query vector and prepares the PQ table distances for efficient computation during search operations.