Modules
Structs
- A1
- Alignment witness for PowerOfTwo::V1 bytes.
- A512
- Alignment witness for PowerOfTwo::V512 bytes.
- Aligned
File Reader Factory - Aligned
Read - Disk-IO read request, parameterized by its required memory alignment
A. - Storage
Provider Aligned File Reader - Windows
Aligned File Reader - AlignedFileReader for Windows. When you modify this class run the benchmarks to make sure we don’t regress on runtime.
Traits
- Alignment
- Type-level memory-alignment witness for
AlignedRead. Each implementor is a unit type carrying a singlePowerOfTwovalue.