pub struct DiskSearchStrategy<'a, Data, ProviderFactory>{ /* private fields */ }Trait Implementations
Sourceimpl<'this, Data, ProviderFactory> DefaultPostProcessor<'this, DiskProvider<Data>, &'this [<Data as GraphDataType>::VectorDataType], (<DiskProvider<Data> as DataProvider>::InternalId, <Data as GraphDataType>::AssociatedDataType)> for DiskSearchStrategy<'this, Data, ProviderFactory>
impl<'this, Data, ProviderFactory> DefaultPostProcessor<'this, DiskProvider<Data>, &'this [<Data as GraphDataType>::VectorDataType], (<DiskProvider<Data> as DataProvider>::InternalId, <Data as GraphDataType>::AssociatedDataType)> for DiskSearchStrategy<'this, Data, ProviderFactory>
Sourcetype Processor = RerankAndFilter<'this>
type Processor = RerankAndFilter<'this>
The default post-processor type.
Sourcefn default_post_processor(&'this self) -> Self::Processor
fn default_post_processor(&'this self) -> Self::Processor
Create the default post-processor.
Sourceimpl<'this, Data, ProviderFactory> SearchStrategy<'this, DiskProvider<Data>, &'this [<Data as GraphDataType>::VectorDataType]> for DiskSearchStrategy<'this, Data, ProviderFactory>
impl<'this, Data, ProviderFactory> SearchStrategy<'this, DiskProvider<Data>, &'this [<Data as GraphDataType>::VectorDataType]> for DiskSearchStrategy<'this, Data, ProviderFactory>
Sourcetype SearchAccessor = DiskAccessor<'this, Data, <ProviderFactory as VertexProviderFactory<Data>>::VertexProviderType>
type SearchAccessor = DiskAccessor<'this, Data, <ProviderFactory as VertexProviderFactory<Data>>::VertexProviderType>
The concrete type of the accessor that is used to access
Self during the greedy
graph search. The query will be provided to the accessor exactly once during search
to construct the query computer.Sourcetype SearchAccessorError = ANNError
type SearchAccessorError = ANNError
An error that can occur when getting a search_accessor.
Sourcefn search_accessor(
&'this self,
provider: &'this DiskProvider<Data>,
_context: &DefaultContext,
query: &'this [Data::VectorDataType],
) -> Result<Self::SearchAccessor, Self::SearchAccessorError>
fn search_accessor( &'this self, provider: &'this DiskProvider<Data>, _context: &DefaultContext, query: &'this [Data::VectorDataType], ) -> Result<Self::SearchAccessor, Self::SearchAccessorError>
Construct and return the search accessor.