Structs
- Disk
Index Reader - This struct is used by the DiskIndexSearcher to read the index data from storage. Noted that the index data here is different from index graph, It includes the PQ data, pivot table, and the warmup query data. The Storage acts as a provider to read the data from storage system. The storage provider should be provided as a generic type and be specified by the caller when it initializes the DiskIndexSearcher.