Module quant

Module quant 

Structs

GeneratorContext
GeneratorContext defines parameters for vector quantization checkpoint state
PQGeneration
PQGenerationContext
QuantDataGenerator
QuantDataGenerator orchestrates the process of reading vector data, applying quantization, and writing compressed results to storage. It resumes data generation from the checkpoint manager and processes data in batches.

Enums

CompressionStage
CompressionStage defines the stage of compression used by the compressor to determine how to instantiate the quantizer (e.g., whether to initialize codebooks for a product quantizer). Passed to QuantCompressor::new_at_stage when creating quantizer instances.

Traits

QuantCompressor
QuantCompressor defines the interface for quantizer with [QuantDataGenerator]