CompressionStage

Enum CompressionStage 

pub enum CompressionStage {
    Start,
    Resume,
}
CompressionStage defines the stage of compression used by the compressor to determine how to instantiate the quantizer (e.g., whether to initialize codebooks for a product quantizer). Passed to QuantCompressor::new_at_stage when creating quantizer instances.

Variants



Start



Resume