pub enum PQTable {
Transposed(TransposedTable),
Fixed(FixedChunkPQTable),
}Expand description
Behind the scenes, we can use either the FixedChunkPQTable or a
diskann_quantization::product::TransposedTable. The TransposedTable is much faster
for preprocessing, but does not support removal of the dataset centroid.
So, we can only use the TransposedTable when the dataset centroid
is all zero.
Variants
Transposed(TransposedTable)
Fixed(FixedChunkPQTable)