pub struct GeneratorContext {
pub offset: usize,
pub compressed_data_path: String,
}Expand description
GeneratorContext defines parameters for vector quantization checkpoint state
This struct holds offset position that allows resuming quantization from a specific point in the dataset as well as the data path to store the compressed vectors.
Fields
offset: usizeoffset: The point index to start/resume quantization from (for checkpoint support)
compressed_data_path: Stringcompressed_data_path: The path to which to write compressed data to.
Implementations