pub struct PQData { /* private fields */ }Implementations
Sourceimpl PQData
impl PQData
pub fn new( pq_pivot_table: FixedChunkPQTable, pq_compressed_data: Matrix<u8>, ) -> ANNResult<Self>
Sourcepub fn pq_table(&self) -> &TransposedTable
pub fn pq_table(&self) -> &TransposedTable
Get pq_table
Sourcepub fn get_dim(&self) -> usize
pub fn get_dim(&self) -> usize
Return the logical dimension of the original (pre-quantization) vectors.
Sourcepub fn get_num_chunks(&self) -> usize
pub fn get_num_chunks(&self) -> usize
Return the number of chunks in the underlying PQ schema.
Sourcepub fn get_num_centers(&self) -> usize
pub fn get_num_centers(&self) -> usize
Return the number of centers in the underlying PQ schema.
Sourcepub fn pq_compressed_data(&self) -> &Matrix<u8>
pub fn pq_compressed_data(&self) -> &Matrix<u8>
Get pq_compressed_data
pub fn get_compressed_vector(&self, vector_id: usize) -> ANNResult<&[u8]>