WindowsAlignedFileReader

Struct WindowsAlignedFileReader 

pub struct WindowsAlignedFileReader { /* private fields */ }
AlignedFileReader for Windows. When you modify this class run the benchmarks to make sure we don’t regress on runtime.

Run this before making your code change

cargo bench –bench bench_main -p diskann – –save-baseline prior_to_change

Run this after making your code change to generate comparison metrics

cargo bench –bench bench_main -p diskann – –baseline prior_to_change

Implementations