Structs
- Query
Statistics - A struct to gather statistics for a given disk query execution.
Functions
- get_
mean_ stats - Calculates the mean value of a specific metric in a list of QueryStats.
- get_
percentile_ stats - Calculates the percentile value of a specific metric in a list of QueryStats.
- get_
sum_ stats