Structs
- Cache
- Graph
Header - GraphHeader. The header is stored in the first sector of the disk index file, or the first segment of the JET stream.
- Graph
Layout Version - Graph layout version. In the format of
major.minor. - Graph
Metadata - Index graph metadata. The metadata is stored in the first sector of the disk index file, or the first segment of the BigStorageStream. The metadata is like a “header” of the index graph.