Module data_model

Module data_model 

Structs

Cache
GraphHeader
GraphHeader. The header is stored in the first sector of the disk index file, or the first segment of the JET stream.
GraphLayoutVersion
Graph layout version. In the format of major.minor.
GraphMetadata
Index graph metadata. The metadata is stored in the first sector of the disk index file, or the first segment of the BigStorageStream. The metadata is like a “header” of the index graph.

Enums

CachingStrategy