pub struct GraphHeader { /* private fields */ }Expand description
GraphHeader. The header is stored in the first sector of the disk index file, or the first segment of the JET stream.
Implementations
Sourceimpl GraphHeader
impl GraphHeader
Sourcepub const CURRENT_LAYOUT_VERSION: GraphLayoutVersion
pub const CURRENT_LAYOUT_VERSION: GraphLayoutVersion
Update the layout version when the GraphHeader layout is modified.
pub fn new( metadata: GraphMetadata, block_size: u64, layout_version: GraphLayoutVersion, ) -> Self
Sourcepub fn to_bytes(&self) -> ANNResult<Vec<u8>>
pub fn to_bytes(&self) -> ANNResult<Vec<u8>>
Serialize the GraphHeader object to a byte vector.
Layout:
| GraphMetadata (80 bytes) | BlockSize (8 bytes) | GraphLayoutVersion (8 bytes) |
pub fn metadata(&self) -> &GraphMetadata
pub fn block_size(&self) -> u64
pub fn layout_version(&self) -> &GraphLayoutVersion
Sourcepub fn max_degree<DataType>(&self) -> Result<usize, GraphHeaderError>
pub fn max_degree<DataType>(&self) -> Result<usize, GraphHeaderError>
Returns the maximum degree of the graph
Type Parameters
DataType- The type of vector data stored in the graph nodes