pub struct GraphLayoutVersion {
pub major: u32,
pub minor: u32,
}Expand description
Graph layout version. In the format of major.minor.
Fields
major: u32minor: u32Implementations
Sourceimpl GraphLayoutVersion
impl GraphLayoutVersion
pub const fn new(major: u32, minor: u32) -> Self
pub fn major_version(&self) -> u32
pub fn minor_version(&self) -> u32
Sourcepub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn to_bytes(&self) -> Vec<u8> ⓘ
Serialize the GraphLayoutVersion object to a byte vector with 8 bytes.
Layout:
| MajorVersion (4 bytes) | MinorVersion (4 bytes) |
The layout_version contains two parts. The first 32 bits are the major version number in u32 format, and the last 32 bits are the minor version number in u32 format.
Backward incompatible layout changes should increment the major version number while backward compatible changes increments the minor version number.