pub struct GraphMetadata {
pub num_pts: u64,
pub dims: usize,
pub medoid: u64,
pub node_len: u64,
pub num_nodes_per_block: u64,
pub vamana_frozen_num: u64,
pub vamana_frozen_loc: u64,
pub disk_index_file_size: u64,
pub associated_data_length: usize,
}Expand description
Index graph metadata. The metadata is stored in the first sector of the disk index file, or the first segment of the BigStorageStream. The metadata is like a “header” of the index graph.
Fields
num_pts: u64dims: usizemedoid: u64node_len: u64num_nodes_per_block: u64vamana_frozen_num: u64vamana_frozen_loc: u64disk_index_file_size: u64associated_data_length: usizeImplementations
Sourceimpl GraphMetadata
impl GraphMetadata
Sourcepub fn new(
num_pts: u64,
dims: usize,
medoid: u64,
node_len: u64,
num_nodes_per_sector: u64,
vamana_frozen_num: u64,
vamana_frozen_loc: u64,
disk_index_file_size: u64,
data_size: usize,
) -> Self
pub fn new( num_pts: u64, dims: usize, medoid: u64, node_len: u64, num_nodes_per_sector: u64, vamana_frozen_num: u64, vamana_frozen_loc: u64, disk_index_file_size: u64, data_size: usize, ) -> Self
Create a new GraphMetadata object.
Sourcepub fn to_bytes(&self) -> ANNResult<Vec<u8>>
pub fn to_bytes(&self) -> ANNResult<Vec<u8>>
Serialize the GraphMetadata object to a byte vector.
Layout: |number_of_points (8 bytes)| dimensions (8 bytes) | medoid (8 bytes) | node_len (8 bytes) | num_nodes_per_sector (8 bytes) | vamana_frozen_point_num (8 bytes) | …| vamana_frozen_loc (8 bytes) | append_reorder_data (8 bytes) | disk_index_file_size (8 bytes) | associated_data_length (8 bytes) | The append_reorder_data is not used in the rust version. We are just keeping it in the stream to make the file based disk index layout consistent with the C++ version.
pub fn get_size() -> usize