pub struct LinuxAlignedFileReader { /* private fields */ }Implementations
Sourceimpl LinuxAlignedFileReader
AlignedFileReader for Linux. When you modify this class run the benchmarks to make sure
we don’t regress on runtime.
impl LinuxAlignedFileReader
AlignedFileReader for Linux. When you modify this class run the benchmarks to make sure we don’t regress on runtime.