Disk-specific storage operations.
This module contains storage utilities and types specific to disk index operations.
Modules
Structs
- Cached
Reader - Sequential cached reads with a generic storage provider with read access.
- Cached
Writer - Sequential cached writes with a generic storage provider with write access.
- Disk
Index Writer - DiskIndexWriter is used to write disk index data to the storage system. The storage system and data types are provided as parameters to methods that need them.