pub struct DiskIndexReader<VectorType> { /* private fields */ }Expand description
This struct is used by the DiskIndexSearcher to read the index data from storage. Noted that the index data here is different from index graph, It includes the PQ data, pivot table, and the warmup query data. The Storage acts as a provider to read the data from storage system. The storage provider should be provided as a generic type and be specified by the caller when it initializes the DiskIndexSearcher.
Implementations
Sourceimpl<VectorType> DiskIndexReader<VectorType>
impl<VectorType> DiskIndexReader<VectorType>
Sourcepub fn new<Storage: StorageReadProvider>(
pq_pivot_path: String,
pq_compressed_data_path: String,
storage_provider: &Storage,
) -> ANNResult<Self>
pub fn new<Storage: StorageReadProvider>( pq_pivot_path: String, pq_compressed_data_path: String, storage_provider: &Storage, ) -> ANNResult<Self>
Create DiskIndexReader instance
pub fn get_pq_data(&self) -> Arc<PQData>
pub fn get_num_points(&self) -> usize