Structs
- Generator
Context GeneratorContextdefines parameters for vector quantization checkpoint state- PQData
- PQGeneration
- PQGeneration
Context - Quant
Data Generator QuantDataGeneratororchestrates the process of reading vector data, applying quantization, and writing compressed results to storage. It resumes data generation from the checkpoint manager and processes data in batches.
Enums
- Compression
Stage CompressionStagedefines the stage of compression used by the compressor to determine how to instantiate the quantizer (e.g., whether to initialize codebooks for a product quantizer). Passed toQuantCompressor::new_at_stagewhen creating quantizer instances.- PQTable
- Behind the scenes, we can use either the
FixedChunkPQTableor adiskann_quantization::product::TransposedTable. TheTransposedTableis much faster for preprocessing, but does not support removal of the dataset centroid.
Traits
- Quant
Compressor QuantCompressordefines the interface for quantizer with [QuantDataGenerator]