pub struct PerfLogger { /* private fields */ }Implementations
Sourceimpl PerfLogger
impl PerfLogger
pub fn new<T: Display>(scenario: T, enable_logging: bool) -> Self
pub fn new_disk_index_build_logger() -> Self
Sourcepub fn log_checkpoint<T: Display>(&mut self, checkpoint: T)
pub fn log_checkpoint<T: Display>(&mut self, checkpoint: T)
Logs the time elapsed since the last checkpoint or since the logger was created.
This method calculates the elapsed time, logs it with the provided checkpoint name, and then resets the start time to the current time. If logging is not enabled, this method does nothing.
Arguments
checkpoint- A string slice that holds the name of the checkpoint.
Examples
use diskann_disk::utils::instrumentation::PerfLogger;
let mut logger = PerfLogger::new("Scenario".to_string(), true);
logger.log_checkpoint("Checkpoint1");Sourcepub fn log_enabled(&self) -> bool
pub fn log_enabled(&self) -> bool
Returns whether logging is enabled for the perf logger.